#include <util/delay.h>

#include "usart.h"
#include "vibration_sensor.h"
#include "servo.h"
#include "led.h"
#include "timer.h"
#include "knock_module.h"

void initialise_environment(void)
{
	/* Sets the PD6 pin (push button) as input */
	DDRD &= ~(1 << PD6);
	
	/* Initializes the LEDs */
	LED_init();
	
	/* Initializes the USART controller */
	USART_init();
	
	/* Initializes the ADC */
	ADC_init();
	
	/* Initializes the micro servo */
	servo_init();
	
	/* Initializes the global timer */
	timer_init();
	
	/* Lights the blue LED and the green LED to simulate a loading */
	PORTD |= (1 << PD7);
	PORTC |= (1 << PC0);
	_delay_ms(1000);
}

int main(void)
{
	initialise_environment();
	
	while(1)
	{
		if ((PIND & (1 << PD6)) == 0) {
			/* Turns off the both of the leds */
			PORTC &= ~(1 << PC0);
			PORTD &= ~(1 << PD7);

			_delay_ms(500);
			
			program_knock();
		} else {
			/* Turns off the both of the leds */
			PORTC &= ~(1 << PC0);
			PORTD &= ~(1 << PD7);
		
			listen_knock();
		}
		
		#ifdef DEBUG
		ADC_print();
		#endif
	}
	
	// while (1) {
	// 	servo_set_unlock_position();
	// 	_delay_ms(500);
	// 	servo_set_lock_position();
	// 	_delay_ms(500);
	// }
	// return 0;
}
