#include "usart.h"

/*
 * Initializes the USART controller
 */
void USART_init(void)
{
    /* Sets the baud rate at 19200 */
    UBRR0H = 0;
    UBRR0L = 51;

    /* starts the transmitter */
    UCSR0B = (1 << TXEN0) | (1 << RXEN0);

    /* sets the frame format: 8 data bits, 1 stop bit, even parity */
    UCSR0C &= ~(1 << USBS0);
    UCSR0C |= (2 << UCSZ00);
    UCSR0C |= (1 << UPM01);
}

/*
 * Transmits a character via the USART
 *
 * @param data - the character to be transmitted
 */
void USART_transmit(char data)
{
    /* waits until the buffer is empty */
    while(!(UCSR0A & (1 << UDRE0)));

    /* 
	 * puts the data in a buffer; the transmition
	 * will start automatically as a result of writing
	 */
    UDR0 = data;
}

/*
 * Transmits a string via the USART
 *
 * @param data - the string to be transmitted
 */
void USART_print(const char *data)
{
    while(*data != '\0')
        USART_transmit(*data++);
}
