#include "vibration_sensor.h"

/*
 * Initializes the Analog-Digital Converter
 */
void ADC_init(void)
{
	ADMUX = (1 << REFS0);
	ADCSRA = (1 << ADEN) | (7 << ADPS0);
}

/*
 * Gets the current value from the specified channel
 *
 * @param channel - the channel where to read data from
 */
int ADC_get(int channel)
{
	ADMUX = (ADMUX & ~(0x1f << MUX0)) | channel;

	ADCSRA |= (1 << ADSC);
	
	while (ADCSRA & (1 << ADSC));

	return ADC;
}

/*
 * Converts raw ADC data into voltage
 *
 * @param raw - the raw data to be converted
 */
double ADC_voltage(int raw)
{
	return (double)raw * AREF / 1024.0;
}

/*
 * Returns true if the voltage from the channel
 * is greater that a THRESHOLD
 */
bool is_valid_knock(void)
{
	return ADC_voltage(ADC_get(0)) > THRESHOLD;
}

/*
 * Prints the current value to serial
 * Used for debug purposes
 */
void ADC_print(void)
{
	int i = 0;
	char value[255];
	
	for (i = 0; i < MAX_KNOCKS; i++) {
		sprintf(value, "%d ", OCR1A);
		USART_print(value);
	}
	
	sprintf(value, "\r\n");
	USART_print(value);
}
